document.addEventListener("DOMContentLoaded", function () {
  const calculateBtn = document.getElementById("calculate");
  const resultCard = document.getElementById("resultCard");
  const numbersAheadEl = document.getElementById("numbersAhead");
  const avgTimeEl = document.getElementById("avgTime");
  const estimatedTimeEl = document.getElementById("estimatedTime");

  // Average time per person (in minutes)
  const baseTimePerPerson = 3;
  const timeVariance = 1; // Variance in minutes

  calculateBtn.addEventListener("click", function () {
    const yourNumber = parseInt(document.getElementById("yourNumber").value);
    const currentNumber = parseInt(
      document.getElementById("currentNumber").value,
    );

    if (isNaN(yourNumber) || isNaN(currentNumber)) {
      alert("Please enter valid numbers");
      return;
    }

    if (yourNumber < currentNumber) {
      alert("Your number cannot be less than the current number");
      return;
    }

    const numbersAhead = yourNumber - currentNumber;
    const avgTimePerPerson = baseTimePerPerson + Math.random() * timeVariance;
    const totalWaitTime = numbersAhead * avgTimePerPerson;

    const estimatedTime = new Date();
    estimatedTime.setMinutes(estimatedTime.getMinutes() + totalWaitTime);

    // Update UI
    resultCard.classList.remove("hidden");
    numbersAheadEl.textContent = numbersAhead;
    avgTimeEl.textContent = `${avgTimePerPerson.toFixed(1)} mins`;
    estimatedTimeEl.textContent = formatTime(estimatedTime);

    // Animate the card
    resultCard.style.animation = "none"; // Reset animation
    void resultCard.offsetWidth; // Trigger reflow
    resultCard.style.animation = "fadeIn 0.5s ease-out"; // Restart animation
  });

  function formatTime(date) {
    return date.toLocaleTimeString([], {
      hour: "2-digit",
      minute: "2-digit",
    });
  }

  // Add input validation
  const inputs = document.querySelectorAll('input[type="number"]');
  inputs.forEach((input) => {
    input.addEventListener("input", function () {
      if (this.value < 0) this.value = 0;
    });
  });
});
